[pan: 5/7] try getting both instances...




commit fede21df2024fd0121ba3366ff6d1a9b0c095548
Author: Thomas Tanner <thosrtanner googlemail com>
Date:   Fri Jun 24 20:29:50 2022 +0100

    try getting both instances...

 pan/general/article_number.h | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)
---
diff --git a/pan/general/article_number.h b/pan/general/article_number.h
index 88148e3..e9cf1dc 100644
--- a/pan/general/article_number.h
+++ b/pan/general/article_number.h
@@ -8,7 +8,9 @@ namespace pan {
 
 struct StringView;
 
 //This one is a count of articles, and hence not the same as an article number at all
 class Article_Count
 {
   public:
@@ -20,7 +22,7 @@ class Article_Count
 
     explicit Article_Count(StringView const &);
 
-    explicit operator unsigned long long () const { return val_; }
+    explicit operator type () const { return val_; }
 
     Article_Count &operator=(Article_Count const &val)
     {
@@ -110,7 +112,6 @@ std::ostream &operator<<(std::ostream &os, Article_Count a);
 /** An article number needs a specific size.
  * Some groups can have way over 4 billion articles.
  */
-//typedef uint64_t Article_Number;
 class Article_Number {
   public:
     typedef uint64_t type;
@@ -8,7 +8,9 @@ namespace pan {
 struct StringView;
 
-//This one is a count of articles, and hence not the same as an article number at all
+/** This is a count of articles. It isn't the same thing as an article number,
+ * even if the underlying type is the same.
+ */
 class Article_Count
 {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]